==> ark-4.10.2.tar.xz: ark-4.10.2/plugins/clilhaplugin/kerfuffle_clilha.desktop.cmake <==
[Desktop Entry]
Type=Service
X-KDE-ServiceTypes=Kerfuffle/Plugin
X-KDE-Library=kerfuffle_clilha
X-KDE-PluginInfo-Author=Theofilos Intzoglou
X-KDE-PluginInfo-Email=int.teo@gmail.com
X-KDE-PluginInfo-Name=kerfuffle_clilha
X-KDE-PluginInfo-Version=0.0.1
X-KDE-PluginInfo-Website=http://www.kde.org
X-KDE-PluginInfo-License=GPLv2+
X-KDE-Priority=100
X-KDE-Kerfuffle-APIRevision=1
X-KDE-Kerfuffle-ReadWrite=true
Name=lha archive plugin
Name[bs]=lha arhivni dodatak
Name[ca]=Connector per arxius LHA
Name[ca@valencia]=Connector per arxius LHA
Name[cs]=Modul pro archiv lha
Name[da]=Plugin til lha-arkiver
Name[de]=lha-Archiv-Modul
Name[el]=πρόσθετο αρχειοθήκης lha
Name[es]=Complemento de archivo comprimido LHA
Name[et]=lha-arhiivi plugin
Name[eu]=lha artxibuen plugina
Name[fi]=lha-pakkaustuki
Name[fr]=Module d'archive lha
Name[ga]=Breiseán cartlainne lha
Name[gl]=Complemento para arquivos LHA
Name[hu]=lha modul
Name[ia]=plugin de archivar lha
Name[it]=estensione per archivi lha
Name[kk]=lha архив плагині
Name[km]=កម្មវិធី​ជំនួយ​ប័ណ្ណសារ lha
Name[ko]=LHA 압축 플러그인
Name[lt]=lha archyvo priedas
Name[mr]=lha संग्रह प्लगइन
Name[nb]=Programtillegg for lha-arkiv
Name[nds]=LHA-Archievmoduul
Name[nl]=lha-archiefplug-in
Name[pa]=lha ਅਕਾਇਵ ਪਲੱਗਇਨ
Name[pl]=Wtyczka archiwów lha
Name[pt]='Plugin' de pacotes LHA
Name[pt_BR]=Plugin de arquivos LHA
Name[ro]=Modul de arhivă lha
Name[ru]=Поддержка архивов LHA
Name[sk]=Modul lha archívu
Name[sl]=Vstavek za arhive lha
Name[sr]=Прикључак ЛХА архива
Name[sr@ijekavian]=Прикључак ЛХА архива
Name[sr@ijekavianlatin]=Priključak LHA arhiva
Name[sr@latin]=Priključak LHA arhiva
Name[sv]=Insticksprogram för LHA-arkiv
Name[tr]=lha arşiv eklentisi
Name[uk]=Додаток для архівів LHA
Name[x-test]=xxlha archive pluginxx
Name[zh_CN]=lha 归档插件
Name[zh_TW]=lha 壓縮檔外掛程式
MimeType=@SUPPORTED_CLILHA_MIMETYPES@

==> ark_4.11.2.orig.tar.xz: ark-4.11.2/plugins/clilhaplugin/kerfuffle_clilha.desktop.cmake <==
[Desktop Entry]
Type=Service
X-KDE-ServiceTypes=Kerfuffle/Plugin
X-KDE-Library=kerfuffle_clilha
X-KDE-PluginInfo-Author=Theofilos Intzoglou
X-KDE-PluginInfo-Email=int.teo@gmail.com
X-KDE-PluginInfo-Name=kerfuffle_clilha
X-KDE-PluginInfo-Version=0.0.1
X-KDE-PluginInfo-Website=http://www.kde.org
X-KDE-PluginInfo-License=GPLv2+
X-KDE-Priority=100
X-KDE-Kerfuffle-APIRevision=1
X-KDE-Kerfuffle-ReadWrite=true
Name=lha archive plugin
Name[bs]=lha arhivni dodatak
Name[ca]=Connector per arxius LHA
Name[ca@valencia]=Connector per arxius LHA
Name[cs]=Modul pro archiv lha
Name[da]=Plugin til lha-arkiver
Name[de]=lha-Archiv-Modul
Name[el]=πρόσθετο αρχειοθήκης lha
Name[es]=Complemento de archivo comprimido LHA
Name[et]=lha-arhiivi plugin
Name[eu]=lha artxibuen plugina
Name[fi]=lha-pakkaustuki
Name[fr]=Module externe d'archive « lha »
Name[ga]=Breiseán cartlainne lha
Name[gl]=Complemento para arquivos LHA
Name[hu]=lha modul
Name[ia]=plugin de archivar lha
Name[it]=estensione per archivi lha
Name[kk]=lha архив плагині
Name[km]=កម្មវិធី​ជំនួយ​ប័ណ្ណសារ lha
Name[ko]=LHA 압축 플러그인
Name[lt]=lha archyvo priedas
Name[mr]=lha संग्रह प्लगइन
Name[nb]=Programtillegg for lha-arkiv
Name[nds]=LHA-Archievmoduul
Name[nl]=lha-archiefplug-in
Name[pa]=lha ਅਕਾਇਵ ਪਲੱਗਇਨ
Name[pl]=Wtyczka archiwów lha
Name[pt]='Plugin' de pacotes LHA
Name[pt_BR]=Plugin de arquivos LHA
Name[ro]=Modul de arhivă lha
Name[ru]=Поддержка архивов LHA
Name[sk]=Modul lha archívu
Name[sl]=Vstavek za arhive lha
Name[sr]=Прикључак ЛХА архива
Name[sr@ijekavian]=Прикључак ЛХА архива
Name[sr@ijekavianlatin]=Priključak LHA arhiva
Name[sr@latin]=Priključak LHA arhiva
Name[sv]=Insticksprogram för LHA-arkiv
Name[tr]=lha arşiv eklentisi
Name[uk]=Додаток для архівів LHA
Name[x-test]=xxlha archive pluginxx
Name[zh_CN]=lha 归档插件
Name[zh_TW]=lha 壓縮檔外掛程式
MimeType=@SUPPORTED_CLILHA_MIMETYPES@
